@@ -189,7 +189,7 @@ class MessageProcessor:
               Tracker for `sender_id` if available, `None` otherwise.
         """
 
-        tracker = self._get_tracker(sender_id)
+        tracker = self.get_tracker(sender_id)
         if not tracker:
             return None
 
@@ -197,6 +197,26 @@ class MessageProcessor:
 
         return tracker
 
+    def get_tracker(self, conversation_id: Text) -> Optional[DialogueStateTracker]:
+        """Get the tracker for a conversation.
+
+        In contrast to `get_tracker_with_session_start` this does not add any
+        `action_session_start` or `session_start` events at the beginning of a
+        conversation.
+
+        Args:
+            conversation_id: The ID of the conversation for which the history should be
+                retrieved.
+
+        Returns:
+            Tracker for the conversation. Creates an empty tracker in case it's a new
+            conversation.
+        """
+        conversation_id = conversation_id or UserMessage.DEFAULT_SENDER_ID
+        return self.tracker_store.get_or_create_tracker(
+            conversation_id, append_action_listen=False
+        )
+
     async def log_message(
         self, message: UserMessage, should_save_tracker: bool = True
     ) -> Optional[DialogueStateTracker]:
@@ -713,12 +733,6 @@ class MessageProcessor:
 
         return has_expired
 
-    def _get_tracker(self, sender_id: Text) -> Optional[DialogueStateTracker]:
-        sender_id = sender_id or UserMessage.DEFAULT_SENDER_ID
-        return self.tracker_store.get_or_create_tracker(
-            sender_id, append_action_listen=False
-        )
-
     def _save_tracker(self, tracker: DialogueStateTracker) -> None:
         self.tracker_store.save(tracker)
 
